@@ -26,7 +26,7 @@ import markdown2
 
 PATTERNS = {
     'freelink': re.compile(r'\[\[(.+?)\]\]'), # XXX: should be surrounded by \b
-    'wikilink': re.compile(r'(\b[A-Z][a-z]+[A-Z]\w+\b)')
+    'wikilink': re.compile(r'((?<=\s)[A-Z][a-z]+[A-Z]\w+\b)')
 }
 
 
